summaryrefslogtreecommitdiffstats
path: root/source/slang/slang-parser.cpp
diff options
context:
space:
mode:
authorYong He <yonghe@outlook.com>2022-10-27 12:19:30 -0700
committerGitHub <noreply@github.com>2022-10-27 12:19:30 -0700
commit0cbef6fd6d7924d37ef3ea5ec7c848c80947d13f (patch)
tree173fa18c39638e7d41ae092b9012554cb867a31b /source/slang/slang-parser.cpp
parent351e78f3abc54f114237d4af64f8199476ebf176 (diff)
Rename `__jvp`-->`__fwd_diff`. (#2471)
Co-authored-by: Yong He <yhe@nvidia.com>
Diffstat (limited to 'source/slang/slang-parser.cpp')
-rw-r--r--source/slang/slang-parser.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/source/slang/slang-parser.cpp b/source/slang/slang-parser.cpp
index f2284a121..93f2fcdcb 100644
--- a/source/slang/slang-parser.cpp
+++ b/source/slang/slang-parser.cpp
@@ -2089,11 +2089,11 @@ namespace Slang
{
return parseTaggedUnionType(parser);
}
/// Parse an expression of the form __jvp(fn) where fn is an
/// identifier pointing to a function.
- static Expr* parseJVPDifferentiate(Parser* parser)
+ static Expr* parseForwardDifferentiate(Parser* parser)
{
- JVPDifferentiateExpr* jvpExpr = parser->astBuilder->create<JVPDifferentiateExpr>();
+ ForwardDifferentiateExpr* jvpExpr = parser->astBuilder->create<ForwardDifferentiateExpr>();
parser->ReadToken(TokenType::LParent);
@@ -2104,9 +2104,9 @@ namespace Slang
return jvpExpr;
}
- static NodeBase* parseJVPDifferentiate(Parser* parser, void* /* unused */)
+ static NodeBase* parseForwardDifferentiate(Parser* parser, void* /* unused */)
{
- return parseJVPDifferentiate(parser);
+ return parseForwardDifferentiate(parser);
}
/// Parse a `This` type expression
@@ -6634,7 +6634,7 @@ namespace Slang
_makeParseExpr("none", parseNoneExpr),
_makeParseExpr("try", parseTryExpr),
_makeParseExpr("__TaggedUnion", parseTaggedUnionType),
- _makeParseExpr("__jvp", parseJVPDifferentiate)
+ _makeParseExpr("__fwd_diff", parseForwardDifferentiate)
};
ConstArrayView<SyntaxParseInfo> getSyntaxParseInfos()
@@ -2089,11 +2089,11 @@ namespace Slang
return parseTaggedUnionType(parser);
}
- /// Parse an expression of the form __jvp(fn) where fn is an
+ /// Parse an expression of the form __fwd_diff(fn) where fn is an
/// identifier pointing to a function.